@@ -2,6 +2,7 @@
 import logging
 
 from .atc import parse_atc
+from .bluemaestro import parse_bluemaestro
 from .brifit import parse_brifit
 from .govee import parse_govee
 from .inode import parse_inode
@@ -19,7 +20,15 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class BleParser:
-    def __init__(self, report_unknown=False, discovery=True, filter_duplicates=False, sensor_whitelist=[], tracker_whitelist=[], aeskeys={}):
+    def __init__(
+        self,
+        report_unknown=False,
+        discovery=True,
+        filter_duplicates=False,
+        sensor_whitelist=[],
+        tracker_whitelist=[],
+        aeskeys={}
+    ):
         self.report_unknown = report_unknown
         self.discovery = discovery
         self.filter_duplicates = filter_duplicates
@@ -101,8 +110,8 @@ class BleParser:
                         sensor_data = parse_thermoplus(self, adstruct, mac, rssi)
                         break
                     if adstruct[0] == 0x0C and comp_id == 0xEC88:  # Govee H5051
-                         sensor_data = parse_govee(self, adstruct, mac, rssi)
-                         break
+                        sensor_data = parse_govee(self, adstruct, mac, rssi)
+                        break
                     if adstruct[0] == 0x0A and comp_id == 0xEC88:  # Govee H5074
                         sensor_data = parse_govee(self, adstruct, mac, rssi)
                         break
@@ -118,9 +127,6 @@ class BleParser:
                     if adstruct[0] == 0x0C and comp_id == 0x8801:  # Govee H5179
                         sensor_data = parse_govee(self, adstruct, mac, rssi)
                         break
-                    if adstruct[0] == 0x15 and comp_id == 0x1000:  # Moat S2
-                        sensor_data = parse_moat(self, adstruct, mac, rssi)
-                        break
                     if comp_id == 0x0499:  # Ruuvitag V3/V5
                         sensor_data = parse_ruuvitag(self, adstruct, mac, rssi)
                         break
@@ -130,6 +136,12 @@ class BleParser:
                     if adstruct[0] == 0x0E and adstruct[3] == 0x82:  # iNode
                         sensor_data = parse_inode(self, adstruct, mac, rssi)
                         break
+                    if adstruct[0] == 0x15 and comp_id == 0x1000:  # Moat S2
+                        sensor_data = parse_moat(self, adstruct, mac, rssi)
+                        break
+                    if adstruct[0] == 0x11 and comp_id == 0x0133:  # BlueMaestro
+                        sensor_data = parse_bluemaestro(self, adstruct, mac, rssi)
+                        break
                 elif adstuct_type == 0x06 and adstuct_size > 16:
                     sensorpush_uuid_reversed = b'\xb0\x0a\x09\xec\xd7\x9d\xb8\x93\xba\x42\xd6\x11\x00\x00\x09\xef'
                     if str(adstruct[2:]) == str(sensorpush_uuid_reversed):
